| logsumexp | R Documentation |
These functions are small chunks of code designed to decompose the computation of the EM algorithm into simpler steps.
logsumexp returns the computation of equation \log(\exp(sum(x))), avoiding numerical overflows
logsumexp(l)
predict_posterior_probability(x, estimated_theta)
l |
a vector of numeric terms |
x |
the vector of observed values, of size |
estimated_theta |
the estimated parameters |
a numeric scalar value, result of the previously described equation
a list with two elements:
the posterior probability matrix, eta: \eta=(\eta_{i,j}) \in [0, 1]^{n \times k}, with \eta_{i,j}
giving the posterior probability of observation i to belong to cluster j
loglik returns the expected log-likelihood of our experiment
predict_posterior_probability(): predict_posterior_probability returns the expected probability for each observation
to belong to any of the k clusters set a priori, given the estimated parameters
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.